==> jc-1.4.0.tar.gz: soot/coffi/UnusuableType.h <==
// public class soot.coffi.UnusuableType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 4827ace502dffeb2 soot_coffi_UnusuableType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_coffi_UnusuableType_H_
#define _JC_soot_coffi_UnusuableType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_UnusuableType$object;

// Typedefs
typedef struct _jc_soot_coffi_UnusuableType$sub_refs	_jc_soot_coffi_UnusuableType$sub_refs;
typedef struct _jc_soot_coffi_UnusuableType$sub_nonrefs	_jc_soot_coffi_UnusuableType$sub_nonrefs;
typedef struct _jc_soot_coffi_UnusuableType$refs	_jc_soot_coffi_UnusuableType$refs;
typedef struct _jc_soot_coffi_UnusuableType$nonrefs	_jc_soot_coffi_UnusuableType$nonrefs;
typedef struct _jc_soot_coffi_UnusuableType$object	_jc_soot_coffi_UnusuableType$object;

typedef const struct _jc_soot_coffi_UnusuableType$vmethods	_jc_soot_coffi_UnusuableType$vmethods;
typedef const struct _jc_soot_coffi_UnusuableType$vtable	_jc_soot_coffi_UnusuableType$vtable;
typedef const struct _jc_soot_coffi_UnusuableType$vtype	_jc_soot_coffi_UnusuableType$vtype;

// Constructors
extern void _jc_soot_coffi_UnusuableType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern jboolean _jc_soot_coffi_UnusuableType$method$equals$dd57a1aca6ace081(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Type$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_UnusuableType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_UnusuableType$method_info$equals$dd57a1aca6ace081;
extern _jc_method _jc_soot_coffi_UnusuableType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_coffi_UnusuableType$object *_jc_soot_coffi_UnusuableType$method$v$6c3b425361334da5(_jc_env *);

// Virtual methods structure
struct _jc_soot_coffi_UnusuableType$vmethods {
	jboolean	(*equals$dd57a1aca6ace081)(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Type$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *);
};

// Vtable
struct _jc_soot_coffi_UnusuableType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_coffi_UnusuableType$vmethods	soot_coffi_UnusuableType;
};

// Vtype
struct _jc_soot_coffi_UnusuableType$vtype {
	_jc_type			type;
	_jc_soot_coffi_UnusuableType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_UnusuableType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_UnusuableType$refs {
    _jc_soot_coffi_UnusuableType$sub_refs	soot_coffi_UnusuableType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_UnusuableType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_UnusuableType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_coffi_UnusuableType$sub_nonrefs	soot_coffi_UnusuableType;
};

// Object instance structure
struct _jc_soot_coffi_UnusuableType$object {
	_jc_soot_coffi_UnusuableType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_UnusuableType$vtype	*vtype;
	_jc_soot_coffi_UnusuableType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_UnusuableType$vtype _jc_soot_coffi_UnusuableType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_UnusuableType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_UnusuableType$class_object;

#endif	/* _JC_soot_coffi_UnusuableType_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/UnusuableType.h <==
// public class soot.coffi.UnusuableType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f801e5c664424a1 soot_Type
// @dep_class 4827ace502dffeb2 soot_coffi_UnusuableType

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_coffi_UnusuableType_H_
#define _JC_soot_coffi_UnusuableType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_coffi_UnusuableType$object;

// Typedefs
typedef struct _jc_soot_coffi_UnusuableType$sub_refs	_jc_soot_coffi_UnusuableType$sub_refs;
typedef struct _jc_soot_coffi_UnusuableType$sub_nonrefs	_jc_soot_coffi_UnusuableType$sub_nonrefs;
typedef struct _jc_soot_coffi_UnusuableType$refs	_jc_soot_coffi_UnusuableType$refs;
typedef struct _jc_soot_coffi_UnusuableType$nonrefs	_jc_soot_coffi_UnusuableType$nonrefs;
typedef struct _jc_soot_coffi_UnusuableType$object	_jc_soot_coffi_UnusuableType$object;

typedef const struct _jc_soot_coffi_UnusuableType$vmethods	_jc_soot_coffi_UnusuableType$vmethods;
typedef const struct _jc_soot_coffi_UnusuableType$vtable	_jc_soot_coffi_UnusuableType$vtable;
typedef const struct _jc_soot_coffi_UnusuableType$vtype	_jc_soot_coffi_UnusuableType$vtype;

// Constructors
extern void _jc_soot_coffi_UnusuableType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_coffi_UnusuableType$method$equals$dd57a1aca6ace081(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_UnusuableType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_UnusuableType$method_info$equals$dd57a1aca6ace081;
extern _jc_method _jc_soot_coffi_UnusuableType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_coffi_UnusuableType$object *_jc_soot_coffi_UnusuableType$method$v$6c3b425361334da5(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_UnusuableType$vmethods {
	jboolean	(*equals$dd57a1aca6ace081)(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_UnusuableType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_UnusuableType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_coffi_UnusuableType$vmethods	soot_coffi_UnusuableType;
};

// Vtype
struct _jc_soot_coffi_UnusuableType$vtype {
	_jc_type			type;
	_jc_soot_coffi_UnusuableType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_UnusuableType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_UnusuableType$refs {
    _jc_soot_coffi_UnusuableType$sub_refs	soot_coffi_UnusuableType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_UnusuableType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_UnusuableType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_coffi_UnusuableType$sub_nonrefs	soot_coffi_UnusuableType;
};

// Object instance structure
struct _jc_soot_coffi_UnusuableType$object {
	_jc_soot_coffi_UnusuableType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_UnusuableType$vtype	*vtype;
	_jc_soot_coffi_UnusuableType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_UnusuableType$vtype _jc_soot_coffi_UnusuableType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_UnusuableType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_UnusuableType$class_object;

#endif	/* _JC_soot_coffi_UnusuableType_H_ */
